@@ -2,10 +2,8 @@
 
 Defines how the default settings for isort should be loaded
 """
-import codecs
 import configparser
 import fnmatch
-import glob
 import os
 import posixpath
 import re
@@ -451,11 +449,13 @@ class Config(_Config):
         if "src_paths" not in combined_config:
             combined_config["src_paths"] = (path_root / "src", path_root)
         else:
-            src_paths: List[Path] = []
+            src_paths: Set[Path] = set()
             for src_path in combined_config.get("src_paths", ()):
-                full_path = path_root / src_path
-                if full_path not in src_paths:
-                    src_paths.append(full_path)
+                full_paths = (
+                    path_root.glob(src_path) if "*" in str(src_path) else [path_root / src_path]
+                )
+                for path in full_paths:
+                    src_paths.add(path)
 
             combined_config["src_paths"] = tuple(src_paths)
 
@@ -485,7 +485,8 @@ class Config(_Config):
                 warn(
                     "W0503: Deprecated config options were used: "
                     f"{', '.join(deprecated_options_used)}."
-                    "Please see the 5.0.0 upgrade guide: bit.ly/isortv5."
+                    "Please see the 5.0.0 upgrade guide: "
+                    "https://pycqa.github.io/isort/docs/upgrade_guides/5.0.0.html"
                 )
 
         if known_other:
@@ -537,31 +538,38 @@ class Config(_Config):
             return bool(_SHEBANG_RE.match(line))
 
     def _check_folder_gitignore(self, folder: str) -> Optional[Path]:
+        env = {"LANG": "C.UTF-8"}
         try:
             topfolder_result = subprocess.check_output(  # nosec # skipcq: PYL-W1510
-                ["git", "-C", folder, "rev-parse", "--show-toplevel"]
+                ["git", "-C", folder, "rev-parse", "--show-toplevel"], encoding="utf-8", env=env
             )
-            git_folder = Path(topfolder_result.decode("utf-8").split("\n")[0])
-
-            files = glob.glob(str(git_folder) + "/**/*", recursive=True)
-            files_result = (
-                codecs.escape_decode(  # type: ignore
-                    subprocess.check_output(  # nosec # skipcq: PYL-W1510
-                        ["git", "-C", str(git_folder), "check-ignore", "--stdin"],
-                        input="\n".join(files).encode(),
-                    )
-                )[0]
-                .decode("utf-8")
-                .splitlines()
-            )
-
-            self.git_ignore[git_folder] = {Path(f.strip('"')) for f in files_result}
-
-            return git_folder
-
         except subprocess.CalledProcessError:
             return None
 
+        git_folder = Path(topfolder_result.rstrip()).resolve()
+
+        files: List[str] = []
+        # don't check symlinks; either part of the repo and would be checked
+        # twice, or is external to the repo and git won't know anything about it
+        for root, _dirs, git_files in os.walk(git_folder, followlinks=False):
+            if ".git" in _dirs:
+                _dirs.remove(".git")
+            for git_file in git_files:
+                files.append(os.path.join(root, git_file))
+        git_options = ["-C", str(git_folder), "-c", "core.quotePath="]
+        try:
+            ignored = subprocess.check_output(  # nosec # skipcq: PYL-W1510
+                ["git", *git_options, "check-ignore", "-z", "--stdin", "--no-index"],
+                encoding="utf-8",
+                env=env,
+                input="\0".join(files),
+            )
+        except subprocess.CalledProcessError:
+            return None
+
+        self.git_ignore[git_folder] = {Path(f) for f in ignored.rstrip("\0").split("\0")}
+        return git_folder
+
     def is_skipped(self, file_path: Path) -> bool:
         """Returns True if the file and/or folder should be skipped based on current settings."""
         if self.directory and Path(self.directory) in file_path.resolve().parents:
@@ -571,22 +579,6 @@ class Config(_Config):
 
         os_path = str(file_path)
 
-        if self.skip_gitignore:
-            if file_path.name == ".git":  # pragma: no cover
-                return True
-
-            git_folder = None
-
-            for folder in self.git_ignore:
-                if folder in file_path.parents:
-                    git_folder = folder
-                    break
-            else:
-                git_folder = self._check_folder_gitignore(str(file_path.parent))
-
-            if git_folder and file_path in self.git_ignore[git_folder]:
-                return True
-
         normalized_path = os_path.replace("\\", "/")
         if normalized_path[1:2] == ":":
             normalized_path = normalized_path[2:]
@@ -610,6 +602,23 @@ class Config(_Config):
         if not (os.path.isfile(os_path) or os.path.isdir(os_path) or os.path.islink(os_path)):
             return True
 
+        if self.skip_gitignore:
+            if file_path.name == ".git":  # pragma: no cover
+                return True
+
+            git_folder = None
+
+            file_paths = [file_path, file_path.resolve()]
+            for folder in self.git_ignore:
+                if any(folder in path.parents for path in file_paths):
+                    git_folder = folder
+                    break
+            else:
+                git_folder = self._check_folder_gitignore(str(file_path.parent))
+
+            if git_folder and any(path in self.git_ignore[git_folder] for path in file_paths):
+                return True
+
         return False
 
     @property
