@@ -78,6 +78,7 @@ def test_parse_args():
     assert main.parse_args(["--combine-straight-imports"]) == {"combine_straight_imports": True}
     assert main.parse_args(["--dont-follow-links"]) == {"follow_links": False}
     assert main.parse_args(["--overwrite-in-place"]) == {"overwrite_in_place": True}
+    assert main.parse_args(["--from-first"]) == {"from_first": True}
 
 
 def test_ascii_art(capsys):
@@ -562,7 +563,7 @@ from a import y
 """
     )
 
-    main.main(["-", "--ff", "FROM_FIRST"], stdin=input_content)
+    main.main(["-", "--ff"], stdin=input_content)
     out, error = capsys.readouterr()
 
     assert out == (
@@ -1187,3 +1188,26 @@ nested_dir_ignored
     out, error = main_check([str(tmpdir), "--skip-gitignore", "--filter-files"])
 
     assert all(f"{str(tmpdir)}{file}" in out for file in should_check)
+
+    # Should work when git project contains symlinks
+
+    if os.name != "nt":
+        git_project0.join("has_imports_ignored.py").write(import_content)
+        git_project0.join("has_imports.py").write(import_content)
+        tmpdir.join("has_imports.py").write(import_content)
+        tmpdir.join("nested_dir").join("has_imports.py").write(import_content)
+        git_project0.join("ignore_link.py").mksymlinkto(tmpdir.join("has_imports.py"))
+        git_project0.join("ignore_link").mksymlinkto(tmpdir.join("nested_dir"))
+        git_project0.join(".gitignore").write("ignore_link.py\nignore_link", mode="a")
+
+        out, error = main_check(
+            [str(git_project0), "--skip-gitignore", "--filter-files", "--check"]
+        )
+
+        should_check = ["/git_project0/has_imports.py"]
+
+        assert all(f"{str(tmpdir)}{file}" in error for file in should_check)
+
+        out, error = main_check([str(git_project0), "--skip-gitignore", "--filter-files"])
+
+        assert all(f"{str(tmpdir)}{file}" in out for file in should_check)
